@@ -442,8 +442,9 @@ class SqlAlchemyProxy:
     def backupContext(self):
         try:
             context = self.getContext()
-            for instance in self.session.dirty and instance not in context:
-                context.append(self.load(instance))
+            for instance in self.session.dirty: 
+                if instance not in context:
+                    context.append(self.load(instance))
         except Exception as exception:
             log.warning(self.backupContext, 'Not possible backup context', exception=exception)
 
